#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys
from QonsoView import QonsoView
from PyQt4 import QtGui

app = QtGui.QApplication(sys.argv)

consoWin = QonsoView(sys.argv)
consoWin.show()

sys.exit(app.exec_())
